# Sécurité

## Primitives intégrées

- Garde JWT
- Gestionnaire de clés API
- Profils CORS
- Protecteur CSRF
- Gestionnaire de secrets
- Enregistreur d'audit

## Bonnes pratiques

- Faites pivoter les secrets et les clés
- Utiliser un CORS strict en production
- Appliquer les contrôles d'authentification pour les routes sensibles
- Enregistrez les événements de sécurité avec les ID de corrélation